@@ -1,7 +1,13 @@
 
+context <- function(desc) {
+  renv_tests_init()
+  testthat::context(desc)
+}
+
 test_that <- function(desc, code) {
 
   oldlibpaths <- .libPaths()
+  oldrepos <- getOption("repos")
 
   call <- sys.call()
   call[[1]] <- quote(testthat::test_that)
@@ -10,6 +16,7 @@ test_that <- function(desc, code) {
   newlibpaths <- .libPaths()
 
   reporter <- testthat::get_reporter()
+
   ok <-
     identical(reporter$.context, "Sandbox") ||
     identical(oldlibpaths, newlibpaths)
@@ -19,4 +26,11 @@ test_that <- function(desc, code) {
     stopf("test %s has corrupted libpaths", shQuote(desc))
   }
 
+  newrepos <- getOption("repos")
+  ok <- identical(oldrepos, newrepos)
+  if (!ok) {
+    writeLines(c("", oldrepos, "", newrepos))
+    stopf("test %s has corrupted repos", shQuote(desc))
+  }
+
 }
